@@ -1,3 +1,7 @@
+class CommandFailure(Exception):
+    """ Raise if the command failed to run succesfully """
+
+
 class Command(object):
 
     """
@@ -7,9 +11,11 @@ class Command(object):
         Current this allows a script to retry a command.
     """
 
+    CommandFailure = CommandFailure
+
     def __init__(cmd, command_str, host):
         cmd.command_str = command_str
         cmd.host = host
 
     def retry(self):
-        return self.host.run(self.command_str)
+        self = self.host.run(self.command_str)
